@@ -17,16 +17,15 @@ import logging
 from ibm_botocore import xform_name
 from ibm_botocore.utils import merge_dicts
 
+from ..docs import docstring
 from .action import BatchAction
 from .params import create_request_parameters
 from .response import ResourceHandler
-from ..docs import docstring
-
 
 logger = logging.getLogger(__name__)
 
 
-class ResourceCollection(object):
+class ResourceCollection:
     """
     Represents a collection of resources, which can be iterated through,
     optionally with filtering. Collections automatically handle pagination
@@ -43,22 +42,21 @@ class ResourceCollection(object):
     :param handler: The resource response handler used to create resource
                     instances
     """
+
     def __init__(self, model, parent, handler, **kwargs):
         self._model = model
         self._parent = parent
-        self._py_operation_name = xform_name(
-            model.request.operation)
+        self._py_operation_name = xform_name(model.request.operation)
         self._handler = handler
         self._params = copy.deepcopy(kwargs)
 
     def __repr__(self):
-        return '{0}({1}, {2})'.format(
+        return '{}({}, {})'.format(
             self.__class__.__name__,
             self._parent,
-            '{0}.{1}'.format(
-                self._parent.meta.service_name,
-                self._model.resource.type
-            )
+            '{}.{}'.format(
+                self._parent.meta.service_name, self._model.resource.type
+            ),
         )
 
     def __iter__(self):
@@ -109,8 +107,9 @@ class ResourceCollection(object):
         """
         params = copy.deepcopy(self._params)
         merge_dicts(params, kwargs, append_lists=True)
-        clone = self.__class__(self._model, self._parent,
-                               self._handler, **params)
+        clone = self.__class__(
+            self._model, self._parent, self._handler, **params
+        )
         return clone
 
     def pages(self):
@@ -137,8 +136,7 @@ class ResourceCollection(object):
         cleaned_params = self._params.copy()
         limit = cleaned_params.pop('limit', None)
         page_size = cleaned_params.pop('page_size', None)
-        params = create_request_parameters(
-            self._parent, self._model.request)
+        params = create_request_parameters(self._parent, self._model.request)
         merge_dicts(params, cleaned_params, append_lists=True)
 
         # Is this a paginated operation? If so, we need to get an
@@ -147,17 +145,24 @@ class ResourceCollection(object):
         # page in a list. For non-paginated results, we just ignore
         # the page size parameter.
         if client.can_paginate(self._py_operation_name):
-            logger.debug('Calling paginated %s:%s with %r',
-                         self._parent.meta.service_name,
-                         self._py_operation_name, params)
+            logger.debug(
+                'Calling paginated %s:%s with %r',
+                self._parent.meta.service_name,
+                self._py_operation_name,
+                params,
+            )
             paginator = client.get_paginator(self._py_operation_name)
             pages = paginator.paginate(
-                PaginationConfig={
-                    'MaxItems': limit, 'PageSize': page_size}, **params)
+                PaginationConfig={'MaxItems': limit, 'PageSize': page_size},
+                **params
+            )
         else:
-            logger.debug('Calling %s:%s with %r',
-                         self._parent.meta.service_name,
-                         self._py_operation_name, params)
+            logger.debug(
+                'Calling %s:%s with %r',
+                self._parent.meta.service_name,
+                self._py_operation_name,
+                params,
+            )
             pages = [getattr(client, self._py_operation_name)(**params)]
 
         # Now that we have a page iterator or single page of results
@@ -257,7 +262,7 @@ class ResourceCollection(object):
         return self._clone(page_size=count)
 
 
-class CollectionManager(object):
+class CollectionManager:
     """
     A collection manager provides access to resource collection instances,
     which can be iterated and filtered. The manager exposes some
@@ -300,6 +305,7 @@ class CollectionManager(object):
     :type service_context: :py:class:`~ibm_boto3.utils.ServiceContext`
     :param service_context: Context about the AWS service
     """
+
     # The class to use when creating an iterator
     _collection_cls = ResourceCollection
 
@@ -310,20 +316,20 @@ class CollectionManager(object):
 
         search_path = collection_model.resource.path
         self._handler = ResourceHandler(
-            search_path=search_path, factory=factory,
+            search_path=search_path,
+            factory=factory,
             resource_model=collection_model.resource,
             service_context=service_context,
-            operation_name=operation_name
+            operation_name=operation_name,
         )
 
     def __repr__(self):
-        return '{0}({1}, {2})'.format(
+        return '{}({}, {})'.format(
             self.__class__.__name__,
             self._parent,
-            '{0}.{1}'.format(
-                self._parent.meta.service_name,
-                self._model.resource.type
-            )
+            '{}.{}'.format(
+                self._parent.meta.service_name, self._model.resource.type
+            ),
         )
 
     def iterator(self, **kwargs):
@@ -333,40 +339,48 @@ class CollectionManager(object):
         :rtype: :py:class:`ResourceCollection`
         :return: An iterable representing the collection of resources
         """
-        return self._collection_cls(self._model, self._parent,
-                                    self._handler, **kwargs)
+        return self._collection_cls(
+            self._model, self._parent, self._handler, **kwargs
+        )
 
     # Set up some methods to proxy ResourceCollection methods
     def all(self):
         return self.iterator()
+
     all.__doc__ = ResourceCollection.all.__doc__
 
     def filter(self, **kwargs):
         return self.iterator(**kwargs)
+
     filter.__doc__ = ResourceCollection.filter.__doc__
 
     def limit(self, count):
         return self.iterator(limit=count)
+
     limit.__doc__ = ResourceCollection.limit.__doc__
 
     def page_size(self, count):
         return self.iterator(page_size=count)
+
     page_size.__doc__ = ResourceCollection.page_size.__doc__
 
     def pages(self):
         return self.iterator().pages()
+
     pages.__doc__ = ResourceCollection.pages.__doc__
 
 
-class CollectionFactory(object):
+class CollectionFactory:
     """
     A factory to create new
     :py:class:`CollectionManager` and :py:class:`ResourceCollection`
     subclasses from a :py:class:`~ibm_boto3.resources.model.Collection`
     model. These subclasses include methods to perform batch operations.
     """
-    def load_from_definition(self, resource_name, collection_model,
-                             service_context, event_emitter):
+
+    def load_from_definition(
+        self, resource_name, collection_model, service_context, event_emitter
+    ):
         """
         Loads a collection from a model, creating a new
         :py:class:`CollectionManager` subclass
@@ -393,40 +407,55 @@ class CollectionFactory(object):
 
         # Create the batch actions for a collection
         self._load_batch_actions(
-            attrs, resource_name, collection_model,
-            service_context.service_model, event_emitter)
+            attrs,
+            resource_name,
+            collection_model,
+            service_context.service_model,
+            event_emitter,
+        )
         # Add the documentation to the collection class's methods
         self._load_documented_collection_methods(
-            attrs=attrs, resource_name=resource_name,
+            attrs=attrs,
+            resource_name=resource_name,
             collection_model=collection_model,
             service_model=service_context.service_model,
             event_emitter=event_emitter,
-            base_class=ResourceCollection)
+            base_class=ResourceCollection,
+        )
 
         if service_context.service_name == resource_name:
-            cls_name = '{0}.{1}Collection'.format(
-                service_context.service_name, collection_name)
+            cls_name = '{}.{}Collection'.format(
+                service_context.service_name, collection_name
+            )
         else:
-            cls_name = '{0}.{1}.{2}Collection'.format(
-                service_context.service_name, resource_name, collection_name)
+            cls_name = '{}.{}.{}Collection'.format(
+                service_context.service_name, resource_name, collection_name
+            )
 
-        collection_cls = type(str(cls_name), (ResourceCollection,),
-                              attrs)
+        collection_cls = type(str(cls_name), (ResourceCollection,), attrs)
 
         # Add the documentation to the collection manager's methods
         self._load_documented_collection_methods(
-            attrs=attrs, resource_name=resource_name,
+            attrs=attrs,
+            resource_name=resource_name,
             collection_model=collection_model,
             service_model=service_context.service_model,
             event_emitter=event_emitter,
-            base_class=CollectionManager)
+            base_class=CollectionManager,
+        )
         attrs['_collection_cls'] = collection_cls
         cls_name += 'Manager'
 
         return type(str(cls_name), (CollectionManager,), attrs)
 
-    def _load_batch_actions(self, attrs, resource_name, collection_model,
-                            service_model, event_emitter):
+    def _load_batch_actions(
+        self,
+        attrs,
+        resource_name,
+        collection_model,
+        service_model,
+        event_emitter,
+    ):
         """
         Batch actions on the collection become methods on both
         the collection manager and iterators.
@@ -434,12 +463,23 @@ class CollectionFactory(object):
         for action_model in collection_model.batch_actions:
             snake_cased = xform_name(action_model.name)
             attrs[snake_cased] = self._create_batch_action(
-                resource_name, snake_cased, action_model, collection_model,
-                service_model, event_emitter)
+                resource_name,
+                snake_cased,
+                action_model,
+                collection_model,
+                service_model,
+                event_emitter,
+            )
 
     def _load_documented_collection_methods(
-            factory_self, attrs, resource_name, collection_model,
-            service_model, event_emitter, base_class):
+        factory_self,
+        attrs,
+        resource_name,
+        collection_model,
+        service_model,
+        event_emitter,
+        base_class,
+    ):
         # The base class already has these methods defined. However
         # the docstrings are generic and not based for a particular service
         # or resource. So we override these methods by proxying to the
@@ -456,7 +496,7 @@ class CollectionFactory(object):
             event_emitter=event_emitter,
             collection_model=collection_model,
             service_model=service_model,
-            include_signature=False
+            include_signature=False,
         )
         attrs['all'] = all
 
@@ -470,7 +510,7 @@ class CollectionFactory(object):
             event_emitter=event_emitter,
             collection_model=collection_model,
             service_model=service_model,
-            include_signature=False
+            include_signature=False,
         )
         attrs['filter'] = filter
 
@@ -484,7 +524,7 @@ class CollectionFactory(object):
             event_emitter=event_emitter,
             collection_model=collection_model,
             service_model=service_model,
-            include_signature=False
+            include_signature=False,
         )
         attrs['limit'] = limit
 
@@ -498,13 +538,19 @@ class CollectionFactory(object):
             event_emitter=event_emitter,
             collection_model=collection_model,
             service_model=service_model,
-            include_signature=False
+            include_signature=False,
         )
         attrs['page_size'] = page_size
 
-    def _create_batch_action(factory_self, resource_name, snake_cased,
-                             action_model, collection_model, service_model,
-                             event_emitter):
+    def _create_batch_action(
+        factory_self,
+        resource_name,
+        snake_cased,
+        action_model,
+        collection_model,
+        service_model,
+        event_emitter,
+    ):
         """
         Creates a new method which makes a batch operation request
         to the underlying service API.
@@ -521,6 +567,6 @@ class CollectionFactory(object):
             batch_action_model=action_model,
             service_model=service_model,
             collection_model=collection_model,
-            include_signature=False
+            include_signature=False,
         )
         return batch_action
